<?php return array(
    'root' => array(
        'pretty_version' => 'dev-master',
        'version' => 'dev-master',
        'aliases' => array(),
        'reference' => '179863036854d46cec9da355a0a25321f4f4cc7e',
        'name' => 'mediawiki/advanced-meta',
    ),
    'versions' => array(
        'composer/installers' => array(
            'pretty_version' => 'v1.12.0',
            'version' => '1.12.0.0',
            'aliases' => array(),
            'reference' => 'd20a64ed3c94748397ff5973488761b22f6d3f19',
        ),
        'mediawiki/advanced-meta' => array(
            'pretty_version' => 'dev-master',
            'version' => 'dev-master',
            'aliases' => array(),
            'reference' => '179863036854d46cec9da355a0a25321f4f4cc7e',
        ),
        'roundcube/plugin-installer' => array(
            'replaced' => array(
                0 => '*',
            ),
        ),
        'shama/baton' => array(
            'replaced' => array(
                0 => '*',
            ),
        ),
    ),
);
