<?php

// autoload_static.php @generated by Composer

namespace Composer\Autoload;

class ComposerStaticInit413f76fcabfea79eac672c23f0084c24
{
    public static $prefixLengthsPsr4 = array (
        'C' => 
        array (
            'Composer\\Installers\\' => 20,
        ),
    );

    public static $prefixDirsPsr4 = array (
        'Composer\\Installers\\' => 
        array (
            0 => __DIR__ . '/..' . '/composer/installers/src/Composer/Installers',
        ),
    );

    public static $classMap = array (
        'Composer\\InstalledVersions' => __DIR__ . '/..' . '/composer/InstalledVersions.php',
    );

    public static function getInitializer(ClassLoader $loader)
    {
        return \Closure::bind(function () use ($loader) {
            $loader->prefixLengthsPsr4 = ComposerStaticInit413f76fcabfea79eac672c23f0084c24::$prefixLengthsPsr4;
            $loader->prefixDirsPsr4 = ComposerStaticInit413f76fcabfea79eac672c23f0084c24::$prefixDirsPsr4;
            $loader->classMap = ComposerStaticInit413f76fcabfea79eac672c23f0084c24::$classMap;

        }, null, ClassLoader::class);
    }
}
